"use strict";

module.exports = function (context) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var {
    Syntax,
    RuleError,
    report,
    getSource
  } = context;

  var reportResult = (node, message) => {
    report(node, new RuleError(message, {
      line: 0,
      column: 0
    }));
  };

  var headerNodes = [];
  return {
    [Syntax.Document]() {
      headerNodes = [];
    },

    [Syntax.Header](node) {
      headerNodes.push(node);
    },

    ["".concat(Syntax.Document, ":exit")](node) {
      var {
        children
      } = node; // console.log(node);

      var nextNode = "";
      headerNodes.forEach((node, index) => {
        nextNode = headerNodes[index + 1];

        if (node.depth == 2 && nextNode.raw !== "### 概要") {
          reportResult(node, "タイトルの後に概要がありません。");
        } else if (node.raw === "### 概要" && nextNode.raw !== "### 経験値") {
          reportResult(node, "概要の後に経験値がありません。");
        } else if (node.raw === "### 経験値" && nextNode.raw !== "### 本文") {
          reportResult(node, "経験値の後に本文がありません。");
        } else if (node.raw === "### 本文") {
          var nowNode = children.findIndex(n => n.loc.start.line === node.loc.start.line); // nodeのline ~ ---(HorizontalRule)までに、### 問題があるかどうか

          for (var i = nowNode; i < children.length; i++) {
            if (children[i].raw === "### 問題") {
              break;
            }

            if (children[i].type === "HorizontalRule") {
              // HorizontalRuleがあったら終了
              // TODO: そもそもHorizontalがなかったらエラーが起きないので、Horizontalがレッスンごとに存在しているかルールを作成
              reportResult(node, "本文の後に問題がありません。");
            }
          }
        } else if (node.raw === "### 問題") {
          var _nowNode = children.findIndex(n => n.loc.start.line === node.loc.start.line); // nodeのline ~ ---(HorizontalRule)までに、### 問題があるかどうか


          for (var _i = _nowNode; _i < children.length; _i++) {
            if (children[_i].raw === "### 解説") {
              break;
            }

            if (children[_i].type === "HorizontalRule") {
              reportResult(node, "問題の後に解説がありません。");
            }
          }
        }
      });
    }

  };
};
//# sourceMappingURL=index.js.map